@@ -3,7 +3,7 @@
 Note:
 We don't test performance here, so the test does not predicate
 whether PersistentPg actually will help in improving performance or not.
-We also assume that the underlying SolidPg connections are tested.
+We also assume that the underlying SteadyPg connections are tested.
 
 Copyright and credit info:
 
@@ -11,16 +11,16 @@ Copyright and credit info:
 
 """
 
-__version__ = '0.9.1'
-__revision__ = "$Rev: 5230 $"
-__date__ = "$Date: 2006-05-08 13:50:31 +0200 (Mo, 08 Mai 2006) $"
+__version__ = '0.9.2'
+__revision__ = "$Rev: 5514 $"
+__date__ = "$Date: 2006-07-29 00:50:59 -0600 (Sat, 29 Jul 2006) $"
 
 
 import sys
 
 # This module also serves as a mock object for the pg API module:
 
-import TestSolidPg
+import TestSteadyPg
 
 import unittest
 sys.path.insert(1, '..')
