@@ -3,7 +3,7 @@
 Note:
 We don't test performance here, so the test does not predicate
 whether PooledDB actually will help in improving performance or not.
-We also assume that the underlying SolidDB connections are tested.
+We also assume that the underlying SteadyDB connections are tested.
 
 Copyright and credit info:
 
@@ -11,17 +11,17 @@ Copyright and credit info:
 
 """
 
-__version__ = '0.9.1'
-__revision__ = "$Rev: 5229 $"
-__date__ = "$Date: 2006-05-08 13:40:11 +0200 (Mo, 08 Mai 2006) $"
+__version__ = '0.9.2'
+__revision__ = "$Rev: 5514 $"
+__date__ = "$Date: 2006-07-29 00:50:59 -0600 (Sat, 29 Jul 2006) $"
 
 
 import sys
 
-# The TestSolidDB module serves as a mock object for the DB-API 2 module:
+# The TestSteadyDB module serves as a mock object for the DB-API 2 module:
 
-import TestSolidDB
-dbapi = TestSolidDB
+import TestSteadyDB
+dbapi = TestSteadyDB
 
 import unittest
 sys.path.insert(1, '..')
@@ -71,8 +71,8 @@ class TestPooledDB(unittest.TestCase):
 			self.assert_(hasattr(pool, '_setsession'))
 			self.assert_(pool._setsession is None)
 			con = pool._idle_cache[0]
-			from SolidDB import SolidDBConnection
-			self.assert_(isinstance(con, SolidDBConnection))
+			from SteadyDB import SteadyDBConnection
+			self.assert_(isinstance(con, SteadyDBConnection))
 			self.assert_(hasattr(con, '_maxusage'))
 			self.assertEqual(con._maxusage, 0)
 			self.assert_(hasattr(con, '_setsession_sql'))
@@ -157,8 +157,8 @@ class TestPooledDB(unittest.TestCase):
 				self.assertEqual(shared_con.shared, 1)
 				self.assert_(hasattr(shared_con, 'con'))
 				self.assertEqual(shared_con.con, con)
-			from SolidDB import SolidDBConnection
-			self.assert_(isinstance(con, SolidDBConnection))
+			from SteadyDB import SteadyDBConnection
+			self.assert_(isinstance(con, SteadyDBConnection))
 			self.assert_(hasattr(con, '_con'))
 			db_con = con._con
 			self.assert_(hasattr(db_con, 'num_queries'))
